@@ -24,10 +24,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # greatest(): expected avg(price) to be of type float, found type
             # decimal: https://github.com/cockroachdb/django-cockroachdb/issues/74
             'aggregation.tests.AggregateTestCase.test_expression_on_aggregation',
-            # stddev/variance functions not supported:
-            # https://github.com/cockroachdb/django-cockroachdb/issues/25
-            'aggregation.test_filter_argument.FilteredAggregateTests.test_filtered_numerical_aggregates',
-            'aggregation_regress.tests.AggregationTests.test_stddev',
             # POWER() doesn't support negative exponents:
             # https://github.com/cockroachdb/django-cockroachdb/issues/22
             'db_functions.math.test_power.PowerTests.test_integer',
@@ -47,7 +43,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
             'queries.test_bulk_update.BulkUpdateNoteTests.test_multiple_fields',
             'queries.test_bulk_update.BulkUpdateTests.test_inherited_fields',
             'queries.tests.Queries1Tests.test_ticket9411',
-            'queries.tests.Ticket14056Tests.test_ticket_14056',
             'queries.tests.RelatedLookupTypeTests.test_values_queryset_lookup',
             'syndication_tests.tests.SyndicationFeedTest.test_rss2_feed',
             'syndication_tests.tests.SyndicationFeedTest.test_latest_post_date',
@@ -64,8 +59,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # Unsupported query: mixed type addition in SELECT:
             # https://github.com/cockroachdb/django-cockroachdb/issues/19
             'annotations.tests.NonAggregateAnnotationTestCase.test_mixed_type_annotation_numbers',
-            # Nondeterministic query: https://github.com/cockroachdb/django-cockroachdb/issues/48
-            'queries.tests.SubqueryTests.test_slice_subquery_and_query',
             # Forward references in fixtures won't work until cockroachdb can
             # disable constraints: https://github.com/cockroachdb/cockroach/issues/19444
             'backends.base.test_creation.TestDeserializeDbFromString.test_circular_reference',
@@ -78,11 +71,6 @@ class DatabaseCreation(PostgresDatabaseCreation):
             'serializers.test_data.SerializerDataTests.test_python_serializer',
             'serializers.test_data.SerializerDataTests.test_xml_serializer',
             'serializers.test_data.SerializerDataTests.test_yaml_serializer',
-            # cockroachdb doesn't distinguish between tables and views. Both
-            # are included regardless of whether inspectdb's --include-views
-            # option is set.
-            'inspectdb.tests.InspectDBTransactionalTests.test_include_views',
-            'introspection.tests.IntrospectionTests.test_table_names_with_views',
             # No sequence for AutoField in cockroachdb.
             'introspection.tests.IntrospectionTests.test_sequence_list',
             # Unsupported query: unsupported binary operator: <int> / <int>:
@@ -105,25 +93,20 @@ class DatabaseCreation(PostgresDatabaseCreation):
             # tablespace SQL because cockroachdb automatically indexes foreign
             # keys.
             'model_options.test_tablespaces.TablespacesTests.test_tablespace_for_many_to_many_field',
-            # Unsupported type conversion: https://github.com/cockroachdb/cockroach/issues/9851
+            # ALTER COLUMN TYPE requiring rewrite of on-disk data is currently
+            # not supported for columns that are part of an index.
+            # https://go.crdb.dev/issue/47636
             'migrations.test_executor.ExecutorTests.test_alter_id_type_with_fk',
             'migrations.test_operations.OperationTests.test_alter_field_pk_fk',
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_target_changes',
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_related_name_target_type_change',  # noqa
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_target_changes',  # noqa
             'migrations.test_operations.OperationTests.test_alter_field_reloads_state_on_fk_with_to_field_target_type_change',  # noqa
-            'migrations.test_operations.OperationTests.test_alter_fk_non_fk',
             'migrations.test_operations.OperationTests.test_rename_field_reloads_state_on_fk_target_changes',
             'schema.tests.SchemaTests.test_alter_auto_field_to_char_field',
             'schema.tests.SchemaTests.test_alter_autofield_pk_to_smallautofield_pk_sequence_owner',
-            'schema.tests.SchemaTests.test_alter_text_field_to_date_field',
-            'schema.tests.SchemaTests.test_alter_text_field_to_datetime_field',
-            'schema.tests.SchemaTests.test_alter_text_field_to_time_field',
-            'schema.tests.SchemaTests.test_alter_textual_field_keep_null_status',
             'schema.tests.SchemaTests.test_char_field_pk_to_auto_field',
             'schema.tests.SchemaTests.test_char_field_with_db_index_to_fk',
-            'schema.tests.SchemaTests.test_m2m_rename_field_in_target_model',
-            'schema.tests.SchemaTests.test_rename',
             'schema.tests.SchemaTests.test_text_field_with_db_index_to_fk',
             # cockroachdb doesn't support dropping the primary key.
             'schema.tests.SchemaTests.test_alter_int_pk_to_int_unique',
@@ -155,6 +138,28 @@ class DatabaseCreation(PostgresDatabaseCreation):
             'model_fields.test_jsonfield.TestQuerying.test_ordering_by_transform',
             'model_fields.test_jsonfield.TestQuerying.test_ordering_grouping_by_key_transform',
         )
+        if not self.connection.features.is_cockroachdb_20_2:
+            expected_failures += (
+                # stddev/variance functions not supported:
+                # https://github.com/cockroachdb/django-cockroachdb/issues/25
+                'aggregation.test_filter_argument.FilteredAggregateTests.test_filtered_numerical_aggregates',
+                'aggregation_regress.tests.AggregationTests.test_stddev',
+                # Nondeterministic query: https://github.com/cockroachdb/django-cockroachdb/issues/48
+                'queries.tests.SubqueryTests.test_slice_subquery_and_query',
+                # Unsupported type conversion: https://github.com/cockroachdb/cockroach/issues/9851
+                'migrations.test_operations.OperationTests.test_alter_fk_non_fk',
+                'schema.tests.SchemaTests.test_alter_text_field_to_date_field',
+                'schema.tests.SchemaTests.test_alter_text_field_to_datetime_field',
+                'schema.tests.SchemaTests.test_alter_text_field_to_time_field',
+                'schema.tests.SchemaTests.test_alter_textual_field_keep_null_status',
+                'schema.tests.SchemaTests.test_m2m_rename_field_in_target_model',
+                'schema.tests.SchemaTests.test_rename',
+                # `SHOW TABLES` doesn't distinguish between tables and views.
+                # Both are included regardless of whether inspectdb's
+                # --include-views option is set.
+                'inspectdb.tests.InspectDBTransactionalTests.test_include_views',
+                'introspection.tests.IntrospectionTests.test_table_names_with_views',
+            )
         for test_name in expected_failures:
             test_case_name, _, method_name = test_name.rpartition('.')
             test_app = test_name.split('.')[0]
@@ -241,11 +246,12 @@ class DatabaseCreation(PostgresDatabaseCreation):
         self._clone_db(source_database_name, target_database_name)
 
     def _clone_db(self, source_database_name, target_database_name):
+        connect_args, env = DatabaseClient.settings_to_cmd_args_env(self.connection.settings_dict, [])
         # Chop off ['cockroach', 'sql', '--database=test_djangotests', ...]
-        connect_args = DatabaseClient.settings_to_cmd_args(self.connection.settings_dict)[3:]
+        connect_args = connect_args[3:]
         dump_cmd = ['cockroach', 'dump', source_database_name] + connect_args
         load_cmd = ['cockroach', 'sql', '-d', target_database_name] + connect_args
-        with subprocess.Popen(dump_cmd, stdout=subprocess.PIPE) as dump_proc:
-            with subprocess.Popen(load_cmd, stdin=dump_proc.stdout, stdout=subprocess.DEVNULL):
+        with subprocess.Popen(dump_cmd, stdout=subprocess.PIPE, env=env) as dump_proc:
+            with subprocess.Popen(load_cmd, stdin=dump_proc.stdout, stdout=subprocess.DEVNULL, env=env):
                 # Allow dump_proc to receive a SIGPIPE if the load process exits.
                 dump_proc.stdout.close()
