@@ -7,10 +7,12 @@ from django.db.models import ForeignKey
 
 
 class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
-    # Partial indexes ('%(condition)s' in SQL string) aren't implemented in
-    # cockroachdb: https://github.com/cockroachdb/cockroach/issues/9683
-    # If implemented, this attribute can be removed.
-    sql_create_index = 'CREATE INDEX %(name)s ON %(table)s%(using)s (%(columns)s)%(extra)s'
+    @property
+    def sql_create_index(self):
+        if self.connection.features.is_cockroachdb_20_2:
+            return PostgresDatabaseSchemaEditor.sql_create_index
+        else:
+            return 'CREATE INDEX %(name)s ON %(table)s%(using)s (%(columns)s)%(extra)s'
 
     # The PostgreSQL backend uses "SET CONSTRAINTS ... IMMEDIATE" before
     # "ALTER TABLE..." to run any any deferred checks to allow dropping the
@@ -23,7 +25,15 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
 
     # adding a REFERENCES constraint while also adding a column via ALTER not
     # supported: https://github.com/cockroachdb/cockroach/issues/32917
-    sql_create_column_inline_fk = None
+    @property
+    def sql_create_column_inline_fk(self):
+        if self.connection.features.is_cockroachdb_20_2:
+            # The PostgreSQL backend uses "SET CONSTRAINTS ... IMMEDIATE"
+            # after creating this foreign key. This isn't supported by
+            # CockroachDB.
+            return 'CONSTRAINT %(name)s REFERENCES %(to_table)s(%(to_column)s)%(deferrable)s'
+        else:
+            return None
 
     def _index_columns(self, table, columns, col_suffixes, opclasses):
         # cockroachdb doesn't support PostgreSQL opclasses.
@@ -35,6 +45,10 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
 
     def _alter_field(self, model, old_field, new_field, old_type, new_type,
                      old_db_params, new_db_params, strict=False):
+        # ALTER COLUMN TYPE is experimental.
+        # https://github.com/cockroachdb/cockroach/issues/49329
+        if self.connection.features.is_cockroachdb_20_2 and old_type != new_type:
+            self.execute('SET enable_experimental_alter_column_type_general = true')
         # Skip to the base class to avoid trying to add or drop
         # PostgreSQL-specific LIKE indexes.
         BaseDatabaseSchemaEditor._alter_field(
@@ -63,9 +77,6 @@ class DatabaseSchemaEditor(PostgresDatabaseSchemaEditor):
 
     def _alter_column_type_sql(self, model, old_field, new_field, new_type):
         self.sql_alter_column_type = 'ALTER COLUMN %(column)s TYPE %(type)s'
-        # Cast when data type changed.
-        if self._field_data_type(old_field) != self._field_data_type(new_field):
-            self.sql_alter_column_type += ' USING %(column)s::%(type)s'
         # Make ALTER TYPE with SERIAL make sense.
         # table = strip_quotes(model._meta.db_table)
         serial_fields_map = {'bigserial': 'bigint', 'serial': 'integer', 'smallserial': 'smallint'}
